@@ -1,4 +1,3 @@
-from .errors import *
+from . import errors, indicators
 from .graph import toposort
-from .indicators import *
 from .orchestration import generate_async, generate_sync
